@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.057';
+our $VERSION = '1.058';
 
 use List::Util qw( none any );
 
@@ -59,29 +59,15 @@ sub __delete_table {
 sub __delete_table_confirm {
     my ( $self, $sql, $dbh, $table, $qt_table, $sql_type ) = @_;
     my $stmt = "SELECT * FROM " . $qt_table;
-    #if ( $self->{opt}{G}{max_rows} ) {
-    #    $stmt .= " LIMIT " . $self->{opt}{G}{max_rows};
-    #}
     my $sth = $dbh->prepare( $stmt );
     $sth->execute();
     my $col_names = $sth->{NAME};
     my $all_arrayref = $sth->fetchall_arrayref;
     my $table_rows = @$all_arrayref;
-    #my $table_rows;
-    #if ( $self->{opt}{G}{max_rows} ) {
-    #    my $sth = $dbh->prepare( "SELECT COUNT(*) FROM " . $qt_table );
-    #    $sth->execute();
-    #    $table_rows = ( $sth->fetchrow_array() )[0];
-    #}
-    #else {
-    #    $table_rows = @$all_arrayref;
-    #}
-
-
     unshift @$all_arrayref, $col_names;
     my $prompt_pt = "Table '$table'  -  Close with ENTER";
 
-    print_table( $all_arrayref, { %{$self->{opt}{table}}, prompt => $prompt_pt, max_rows => $self->{opt}{G}{max_rows} } );
+    print_table( $all_arrayref, { %{$self->{opt}{table}}, prompt => $prompt_pt, max_rows => 0 } );
 
     my $auxil = App::DBBrowser::Auxil->new( $self->{info} );
     my $lyt_1 = Term::Choose->new( $self->{info}{lyt_1} );
